@@ -1,6 +1,7 @@
 import threading
 import websocket
 import json
+import asyncio
 
 
 websocket.WebSocket.send_packet = lambda self, x: self.send(json.dumps(x) + '\n')
@@ -49,7 +50,7 @@ class CloudConnection:
 			'method': 'set',
 			'user': self.session.username,
 			'project_id': self.project_id,
-			'name': f'☁️ {variable_name}',
+			'name': f'{chr(9729)} {variable_name}',
 			'value': value
 		})
 
@@ -60,6 +61,12 @@ class CloudConnection:
 		if response['method'] == 'set':
 			self.variables[response['name'][2:]] = response['value']
 
+	async def async_update(self):
+		response = await asyncio.get_event_loop().run_in_executor(None, self.ws.recv)
+		response = json.loads(response)
+		if response['method'] == 'set':
+			self.variables[response['name'][2:]] = response['value']
+
 	def on_cloud_update(self, func):
 		""" Calls func when cloud variables are updated in a thread """
 		def loop(self):
